@@ -24,7 +24,7 @@ getFunctionEnvelopePara <- function(data,R=1000,x){
     return(predict(tmp.lm,newdata=data.frame(x=x)))
   }
   # Fit boot strap
-  b <- boot(data=data,statistic=fn,R=R,x=x)
+  b <- boot::boot(data=data,statistic=fn,R=R,x=x)
   # b contains all the sample predicted values so get this
   tmp <- apply(b$t,2,quantile,probs=c(0.025,0.975))
   bounds <- data.frame(x=x,lwr=tmp[1,],upr=tmp[2,])
